<div align="center">

# 🍋 LMN - LaMbda functionality across servers for Noobs
<!-- <a href="https://github.com/takuma-yoneda/lmn/actions/workflows/python-publish-pypi.yml"> -->
<!--     <img src="https://github.com/takuma-yoneda/lmn/actions/workflows/python-publish-pypi.yml/badge.svg" alt="Publish to PyPI" /> -->
<!-- </a> -->

A lightweight tool to rsync and execute local scripts in a remote machine.

<a href="https://github.com/takuma-yoneda/lmn/actions/workflows/python-run-tests.yml">
    <img src="https://github.com/takuma-yoneda/lmn/actions/workflows/python-run-tests.yml/badge.svg" alt="Test" />
</a>
<a href="https://github.com/takuma-yoneda/lmn">
    <img src="https://tokei.rs/b1/github/takuma-yoneda/lmn" alt="Total lines" />
</a>
<a href="https://pypi.org/project/lmn/">
    <img src="https://img.shields.io/pypi/v/lmn?logo=python&logoColor=%23cccccc" alt="PyPI" />
</a>
</div>

Inspired by [afdaniele/cpk](https://github.com/afdaniele/cpk) and [geyang/jaynes](https://github.com/geyang/jaynes).
